@@ -27,7 +27,7 @@ def interactive():
 
 
 @ns.add_task
-@task(login, aliases=('l',))
+@task(login)
 def enable_logger(logger_name):
     util.enable_logger(logger_name)
 
