@@ -20,6 +20,8 @@ log = logging.getLogger(__name__)
 def makelist(value):
     if not isinstance(value, list):
         if isinstance(value, collections.Iterable):
+            if isinstance(value, six.string_types):
+                return [value]
             return list(value)
         else:
             return [value]
@@ -143,6 +145,9 @@ class REMap(object):
         return {expression.pattern: value
                 for expression, value in self.re_value_pairs}
 
+    def values(self):
+        return self.pattern_to_value.values()
+
 
 class GetAttrGetItem(type):
 
